@@ -20,7 +20,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 */
 // Self
 #include "gvcore.h"
-#include "dialogguard.h"
 
 // Qt
 #include <QApplication>
@@ -29,11 +28,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QImageWriter>
 #include <QLabel>
 #include <QMimeDatabase>
-#include "gwenview_app_debug.h"
 #include <QSpacerItem>
 #include <QSpinBox>
 
-// KDE
+// KF
 #include <KColorScheme>
 #include <KFileCustomDialog>
 #include <KFileWidget>
@@ -41,6 +39,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <KMessageBox>
 
 // Local
+#include "gwenview_app_debug.h"
+#include "dialogguard.h"
 #include <lib/binder.h>
 #include <lib/document/documentfactory.h>
 #include <lib/document/documentjob.h>
@@ -79,7 +79,7 @@ struct GvCorePrivate
         JPEGQualityChooserWidget->setVisible(false); // shown only for JPEGs
 
         QLabel* JPEGQualityChooserLabel = new QLabel;
-        JPEGQualityChooserLabel->setText(i18n("JPEG quality:"));
+        JPEGQualityChooserLabel->setText(i18n("Image quality:"));
         JPEGQualityChooserLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 
         QSpinBox* JPEGQualityChooserSpinBox = new QSpinBox;
@@ -124,10 +124,15 @@ struct GvCorePrivate
         fileWidget->setMimeFilter(supportedMimetypes,
                                             MimeTypeUtils::urlMimeType(url));
 
-        // Only show the JPEG quality chooser when saving a JPEG image
+        // Only show the lossy image quality chooser when saving a lossy image
         QObject::connect(fileWidget, &KFileWidget::filterChanged,
                          JPEGQualityChooserWidget, [=](const QString &filter) {
-            JPEGQualityChooserWidget->setVisible(filter.contains(QLatin1String("jpeg")));
+            JPEGQualityChooserWidget->setVisible(filter.contains(QLatin1String("jpeg")) ||
+                                                 filter.contains(QLatin1String("jxl"))  ||
+                                                 filter.contains(QLatin1String("webp")) ||
+                                                 filter.contains(QLatin1String("avif")) ||
+                                                 filter.contains(QLatin1String("heif")) ||
+                                                 filter.contains(QLatin1String("heic")) );
         });
 
         // Show dialog
@@ -196,10 +201,15 @@ struct GvCorePrivate
             adjustDefaultFullScreenPalette();
         }
 
-        // FullScreenView has textured background
+        // FullScreenView has either a solid black color or a textured background
         pal = mPalettes[GvCore::FullScreenPalette];
-        QString path = QStandardPaths::locate(QStandardPaths::AppDataLocation, "images/background.png");
-        QPixmap bgTexture(path);
+        QPixmap bgTexture(256,256);
+        if (Gwenview::GwenviewConfig::fullScreenBackground() == Gwenview::FullScreenBackground::Black) {
+            bgTexture.fill(Qt::black);
+        } else {
+            QString path = QStandardPaths::locate(QStandardPaths::AppDataLocation, "images/background.png");
+            bgTexture = path;
+        }
         pal.setBrush(QPalette::Base, bgTexture);
         mPalettes[GvCore::FullScreenViewPalette] = pal;
     }
