@@ -26,12 +26,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <QImage>
 #include <QImageWriter>
 #include <QTransform>
-#include "gwenview_lib_debug.h"
 #include <QUrl>
 
-// KDE
+// KF
 
 // Local
+#include "gwenview_lib_debug.h"
 #include "documentjob.h"
 #include "gwenviewconfig.h"
 #include "imageutils.h"
@@ -83,7 +83,13 @@ bool DocumentLoadedImpl::saveInternal(QIODevice* device, const QByteArray& forma
 {
     QImageWriter writer(device, format);
     // If we're saving a non-JPEG image as a JPEG, respect the quality setting
-    if (format == QByteArrayLiteral("jpeg")) {
+    if (format == QByteArrayLiteral("jpeg") ||
+        format == QByteArrayLiteral("jxl")  ||
+        format == QByteArrayLiteral("webp") ||
+        format == QByteArrayLiteral("avif") ||
+        format == QByteArrayLiteral("heif") ||
+        format == QByteArrayLiteral("heic")
+    ) {
         writer.setQuality(GwenviewConfig::jPEGQuality());
     }
     bool ok = writer.write(document()->image());
