@@ -27,15 +27,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <lib/documentview/abstractrasterimageviewtool.h>
 #include <lib/slidecontainer.h>
 #include <lib/zoomwidget.h>
+#include <lib/gwenviewconfig.h>
+#include "gwenview_lib_debug.h"
 
-// KDE
+// KF
 #include <KActionCategory>
 #include <KLocalizedString>
 
 // Qt
 #include <QAction>
 #include <QHBoxLayout>
-#include "gwenview_lib_debug.h"
 
 namespace Gwenview
 {
@@ -53,6 +54,7 @@ struct DocumentViewControllerPrivate
     QAction * mActualSizeAction;
     QAction * mZoomInAction;
     QAction * mZoomOutAction;
+    QAction * mToggleBirdEyeViewAction;
     QList<QAction *> mActions;
 
     void setupActions()
@@ -68,7 +70,7 @@ struct DocumentViewControllerPrivate
         mZoomToFitAction->setIconText(i18nc("@action:button Zoom to fit, shown in status bar, keep it short please", "Fit"));
 
         mZoomToFillAction = view->addAction(QStringLiteral("view_zoom_to_fill"));
-        view->collection()->setDefaultShortcut(mZoomToFillAction, Qt::SHIFT + Qt::Key_F);
+        view->collection()->setDefaultShortcut(mZoomToFillAction, Qt::SHIFT | Qt::Key_F);
         mZoomToFillAction->setCheckable(true);
         mZoomToFillAction->setText(i18n("Zoom to fill window by fitting to width or height"));
         mZoomToFillAction->setIcon(QIcon::fromTheme(QStringLiteral("zoom-fit-best")));
@@ -82,7 +84,14 @@ struct DocumentViewControllerPrivate
         mZoomInAction = view->addAction(KStandardAction::ZoomIn);
         mZoomOutAction = view->addAction(KStandardAction::ZoomOut);
 
-        mActions << mZoomToFitAction << mActualSizeAction << mZoomInAction << mZoomOutAction << mZoomToFillAction;
+        mToggleBirdEyeViewAction = view->addAction(QStringLiteral("view_toggle_birdeyeview"));
+        mToggleBirdEyeViewAction->setCheckable(true);
+        mToggleBirdEyeViewAction->setChecked(GwenviewConfig::birdEyeViewEnabled());
+        mToggleBirdEyeViewAction->setText(i18n("Show Bird's Eye View When Zoomed In"));
+        mToggleBirdEyeViewAction->setIcon(QIcon::fromTheme(QStringLiteral("zoom")));
+        mToggleBirdEyeViewAction->setEnabled(mView != nullptr);
+
+        mActions << mZoomToFitAction << mActualSizeAction << mZoomInAction << mZoomOutAction << mZoomToFillAction << mToggleBirdEyeViewAction;
     }
 
     void connectZoomWidget()
@@ -165,6 +174,8 @@ void DocumentViewController::setView(DocumentView* view)
     connect(d->mZoomOutAction, SIGNAL(triggered()),
             d->mView, SLOT(zoomOut()));
 
+    connect(d->mToggleBirdEyeViewAction, &QAction::triggered, d->mView, &DocumentView::toggleBirdEyeView);
+
     d->updateActions();
     updateZoomToFitActionFromView();
     updateZoomToFillActionFromView();
