@@ -25,9 +25,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QAbstractButton>
 #include <QButtonGroup>
 
-// KDE
-#include <KConfigDialogManager>
-
 // Local
 
 namespace Gwenview
@@ -45,12 +42,12 @@ InvisibleButtonGroup::InvisibleButtonGroup(QWidget* parent)
     hide();
     d->mGroup = new QButtonGroup(this);
     d->mGroup->setExclusive(true);
-    connect(d->mGroup, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &InvisibleButtonGroup::selectionChanged);
-    const QString name = QString::fromLatin1(metaObject()->className());
-    if (!KConfigDialogManager::propertyMap()->contains(name)) {
-        KConfigDialogManager::propertyMap()->insert(name, "current");
-        KConfigDialogManager::changedMap()->insert(name, SIGNAL(selectionChanged(int)));
-    }
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    connect(d->mGroup, &QButtonGroup::idClicked,
+#else
+    connect(d->mGroup, QOverload<int>::of(&QButtonGroup::buttonClicked),
+#endif
+            this, &InvisibleButtonGroup::selectionChanged);
 }
 
 InvisibleButtonGroup::~InvisibleButtonGroup()
